//////////////////////////////////////////////////////////////////////////////
// Module	: Cls118.h														//
// Function	: Board class for Sensoray Model 118 Smart A/D.					//
//////////////////////////////////////////////////////////////////////////////

#ifndef DEF_Cls118
#define DEF_Cls118

#include "ClsIsa.h"		// Base class.

// Logical-to-Physical command opcode mapping table.
static const char Cmd118[] = {
	(const char)0x00,	// CMD_RDCHAN	--	Get data from channel
	(const char)0x10,	// CMD_DFNTYP	--	Declare sensor type
	(const char)0x20,	// CMD_DFNLIM	--	Set alarm limits
	(const char)0x30,	// CMD_RDALRM	--	Get alarm flags for 8 channels
	(const char)0x40,	// CMD_RDTEMP	--	Get TB temperature(s)
	(const char)0x50,	// CMD_DFNOPN	--	Set open-sensor values
	(const char)0x70,	// CMD_TARE		--	Tare gage
	(const char)0x48,	// CMD_FILT50	--	Set 50Hz filter mode
	(const char)0x58,	// CMD_READ8	--	Get data from 8 channels
	(const char)0xFF,	//					 spare
	(const char)0xE0,	// CMD_CAL		--	Calibration function
	(const char)0xF0,	// CMD_DIAGNOSE	--	Diagnostic function
	(const char)0x80,	// CMD_RDSLOP	--	Get gage slope/intercept
	(const char)0x90,	// CMD_WTSLOP	--	Set gage slope/intercept
	(const char)0xB0,	// CMD_GZERO	--	Set gage zero
	(const char)0xD0,	// CMD_GSPAN	--	Set gage span
	(const char)0x60,	// CMD_STFILT	--	Set filter factor
	(const char)0x43,	// CMD_SLEEP	--	Switch to low-power standby
	(const char)0x42,	// CMD_WAKEUP	--	Wake from low-power standby
	(const char)0xC0	// CMD_WCOEFF	--	Set custom-R coefficients
};

// Logical-to-physical SDC mapping table.
static const char Sdc118[] = {
	(const char)0x00,	//  0 : 10V **
	(const char)0x21,	//  1 : 10V
	(const char)0x00,	//  2 : 5V **
	(const char)0x15,	//  3 : 5V
	(const char)0x0E,	//  4 : 1.65V **
	(const char)0x16,	//  5 : 500mV
	(const char)0x17,	//  6 : 100mV
	(const char)0x0D,	//  7 : 80mV **
	(const char)0x01,	//  8 : E
	(const char)0x02,	//  9 : J **
	(const char)0x1B,	// 10 : J
	(const char)0x03,	// 11 : K **
	(const char)0x1C,	// 12 : K
	(const char)0x04,	// 13 : T **
	(const char)0x1D,	// 14 : T
	(const char)0x05,	// 15 : S **
	(const char)0x1E,	// 16 : S
	(const char)0x06,	// 17 : R **
	(const char)0x1F,	// 18 : R
	(const char)0x07,	// 19 : 385 **
	(const char)0x18,	// 20 : 385 platinum
	(const char)0x08,	// 21 : 392 **
	(const char)0x19,	// 22 : 392 platinum
	(const char)0x0B,	// 23 : 10K **
	(const char)0x1A,	// 24 : 10K
	(const char)0x11,	// 25 : 4-20 mA
	(const char)0x0F,	// 26 : Strain/pressure gage
	(const char)0x0A,	// 27 : 400 ohm range
	(const char)0x14,	// 28 : 4K ohm range
	(const char)0x20,	// 29 : 600K ohm range
	(const char)0x0C,	// 30 : Custom resistive sensor
	(const char)0x13,	// 31 : Disabled: remove from scan list
	(const char)0x22,	// 32 : N
	(const char)0x23,	// 33 : C
	(const char)0x24,	// 34 : B
	(const char)0xFF,	// 35 : 120 nickel RTD (STDbus only)
	(const char)0x28,	// 36 : 200 nickel RTD
	(const char)0x29,	// 37 : 1K nickel RTD
	(const char)0x2A,	// 38 : 385 platinum, HiRes (0.0125C)
	(const char)0x2B,	// 39 : 392 platinum, HiRes (0.0125C)
	(const char)0x25,	// 40 : 10K thermistor on fixed 600K ohm range
	(const char)0x2C,	// 41 : 10 ohm copper RTD
	(const char)0x14,	// 42 : 1K nickel RTD (4Kohm range, ext lin)
	(const char)0x14	// 43 : 1K platinum RTD (4Kohm range, ext lin)
};

class Cls118 : public ClsIsa {
public:
	Cls118( long Adrs ) : ClsIsa( 118, Adrs, 8, Sdc118, Cmd118 ) {}
};

#endif // DEF_Cls118
