///////////////////////////////////////////////////////////////////////////////
// Module   : C_Demo.c
// Function : Illustrates how to access SmartAD.DLL from a C/C++ application.
// Usage    : Be sure to compile and link INCSMAD.C to your project.
///////////////////////////////////////////////////////////////////////////////

#include <windows.h>
#include <stdio.h>
#include <conio.h>
#include <time.h>

#include "IncSmad.h"

/////////////////////////////////////////////////////////////////////////////////
#define MODELNUM	7419		// ENTER YOUR SMART A/D MODEL NUMBER HERE
#define ADDRESS		0x01B2		// ENTER YOUR SMART A/D HARDWARE ADDRESS HERE
/////////////////////////////////////////////////////////////////////////////////

// Function prototypes.
long App();

// MAIN APPLICATION FUNCTION ************************************

long main()
{
	long ErrCode;

	// Dynamically link to SmartAD.DLL so we can call DLL functions.
	if ( ErrCode = LinkDLL() )
	{
		printf( "\nError %8X: Problem linking to SmartAD.DLL.\n" );
		return ErrCode;
	}
	else
	{
		// Call some DLL functions.
		ErrCode = App();

		// Application is terminating, so we now disconnect from the DLL.
		UnLinkDLL();
	}

	printf( "\nPress any key to exit.\n" );
	while ( !kbhit() );

	return ErrCode;
}

// CALL SOME SMARTAD.DLL FUNCTIONS ****************************************

long App()
{
	long ErrCode;
	long chan;
	long seconds;

	// Declare Smart A/D board model number and address to the DLL.
	printf( "Declaring board to driver ... " );
	if ( !( SetBoardAttr(0, MODELNUM, ADDRESS) ) )
	{
		printf( "Error: Can't register Smart A/D board\n" );
		return -3;
	}

	// Invoke soft reset.
	printf( "OK\nResetting board ... " );
	ResetBoard( 0 );
	if ( ErrCode = GetFaultFlags(0) )	// Check for any problems.
	{
		printf( "Error %8X: Smart A/D fault flags detected.\n", ErrCode );
		return ErrCode;
	}
	printf( "OK\n" );

	// Configure channels for some various sensor types: chans 0-2 for the +/-5V range,
	// chan 3-4 for the 400 ohm range, and disable channels 5-7.
	for ( chan = 0; chan <= 2; SetSensorType(0, chan++, TYP_VOLTS_5V) );
	for ( chan = 3; chan <= 4; SetSensorType(0, chan++, TYP_OHMS_400) );
	for ( chan = 5; chan <= 7; SetSensorType(0, chan++, TYP_DISABLED) );

	// Wait one second for data to stabilize, then display sensor data at
	// one-second intervals for ten seconds.
	printf( "Sensor data:\n" );
	for ( seconds = 0; seconds < 10; seconds++ )
	{
		Sleep( 1000 );
		for ( chan = 0; chan < 8; chan++ )
			printf( "\nChan %d: %f", chan, GetSensorData(0, chan) );
		printf( "\n" );
	}

	return 0;
}
